@@ -1,19 +1,19 @@
 #! /usr/bin/env python
 
-import os, sys, string
+import os, sys
 
 def help():
-	print "Usage: %s <filename>.kdelnk ..." % sys.argv[0]
+	print("Usage: %s <filename>.kdelnk ..." % sys.argv[0])
 
 if len(sys.argv) < 2:
 	help()
 	sys.exit()
 
 for fn in sys.argv[1:]:
-	print "Doing %s ..." % fn
+	print("Doing %s ..." % fn)
 	f = open(fn, 'r').readlines()
 
-	if string.find(f[0], "# KDE Config") == 0:
+	if f[0].find("# KDE Config") == 0:
 		p = open(fn, 'w')
 		p.writelines(f[1:])
 		p.close()
